# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🚚 Rename dev to core | [221](https://github.com/laminlabs/lnschema-bionty/pull/221) | [falexwolf](https://github.com/falexwolf) | 2024-02-29 | 0.41.0
💚 Fix docs | [220](https://github.com/laminlabs/lnschema-bionty/pull/220) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 |
💚 Fix docstrings | [219](https://github.com/laminlabs/lnschema-bionty/pull/219) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 | 0.40.1
💚 Fix docs | [218](https://github.com/laminlabs/lnschema-bionty/pull/218) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
📝 Update docstrings to use `bionty` | [217](https://github.com/laminlabs/lnschema-bionty/pull/217) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 | 0.40.0
🚚 Rename bionty to bionty-base | [216](https://github.com/laminlabs/lnschema-bionty/pull/216) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
⬆️ Rename Bionty to PublicOntology | [214](https://github.com/laminlabs/lnschema-bionty/pull/214) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-12 | 0.39.0
✏️ Fix encoding | [213](https://github.com/laminlabs/lnschema-bionty/pull/213) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-12 | 0.38.4
🚑️ Re-encode PublicSource | [212](https://github.com/laminlabs/lnschema-bionty/pull/212) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-10 | 0.38.3
🔊 Remove logging | [211](https://github.com/laminlabs/lnschema-bionty/pull/211) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-10 | 0.38.2
⚡️ Speed up previous migration | [210](https://github.com/laminlabs/lnschema-bionty/pull/210) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-10 | 0.38.1
🎨 Encode uid with ontology_id | [209](https://github.com/laminlabs/lnschema-bionty/pull/209) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-10 | 0.38.0
🚚 Rename .bionty to .public | [208](https://github.com/laminlabs/lnschema-bionty/pull/208) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-09 |
🐛 Fix .bionty for global organism | [207](https://github.com/laminlabs/lnschema-bionty/pull/207) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-08 |
🚸 Do not create organism when calling bionty | [206](https://github.com/laminlabs/lnschema-bionty/pull/206) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-08 |
🚚 Rename `Dataset` to `Collection` | [205](https://github.com/laminlabs/lnschema-bionty/pull/205) | [falexwolf](https://github.com/falexwolf) | 2023-12-23 | 0.37.0
♻️ Rename File to Artifact | [201](https://github.com/laminlabs/lnschema-bionty/pull/201) | [falexwolf](https://github.com/falexwolf) | 2023-12-11 | 0.36.0
⬆️ Enabled ID conversion via return_field | [200](https://github.com/laminlabs/lnschema-bionty/pull/200) | [sunnyosun](https://github.com/sunnyosun) | 2023-12-02 |
🐛 Fix save parents with bionty_source | [198](https://github.com/laminlabs/lnschema-bionty/pull/198) | [sunnyosun](https://github.com/sunnyosun) | 2023-11-23 |
✨ Added functions to sync bionty source | [197](https://github.com/laminlabs/lnschema-bionty/pull/197) | [sunnyosun](https://github.com/sunnyosun) | 2023-11-16 | 0.35.1
🚚 Rename FK organism to organisms in BiontySource | [196](https://github.com/laminlabs/lnschema-bionty/pull/196) | [sunnyosun](https://github.com/sunnyosun) | 2023-11-13 | 0.35.0
⬆️ Update bionty | [195](https://github.com/laminlabs/lnschema-bionty/pull/195) | [sunnyosun](https://github.com/sunnyosun) | 2023-11-10 |
⬆️ Upgrade bionty | [194](https://github.com/laminlabs/lnschema-bionty/pull/194) | [sunnyosun](https://github.com/sunnyosun) | 2023-11-09 |
✨ Add parents to Organism | [193](https://github.com/laminlabs/lnschema-bionty/pull/193) | [sunnyosun](https://github.com/sunnyosun) | 2023-10-23 | 0.34.0
🚚 Rename `Species` to `Organism` | [192](https://github.com/laminlabs/lnschema-bionty/pull/192) | [sunnyosun](https://github.com/sunnyosun) | 2023-10-19 | 0.33.0
🚑 Fix bionty_source_uid to be hash id | [191](https://github.com/laminlabs/lnschema-bionty/pull/191) | [sunnyosun](https://github.com/sunnyosun) | 2023-10-18 | 0.32.3
✏️ Fix uid encoder | [190](https://github.com/laminlabs/lnschema-bionty/pull/190) | [sunnyosun](https://github.com/sunnyosun) | 2023-10-18 | 0.32.2
🚚 Migrate to integer primary keys | [188](https://github.com/laminlabs/lnschema-bionty/pull/188) | [falexwolf](https://github.com/falexwolf) | 2023-10-13 | 0.32.0
🔇 Mute repetitive warning for saving parents | [187](https://github.com/laminlabs/lnschema-bionty/pull/187) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-20 | 0.31.2
⬆️ Silence download bar for <5MB files | [186](https://github.com/laminlabs/lnschema-bionty/pull/186) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-08 | 0.31.1
🎨 Return None if no records are created for from_bionty | [185](https://github.com/laminlabs/lnschema-bionty/pull/185) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-07 | 0.31.0
✨ Allow non-default bionty sources in LaminDB | [184](https://github.com/laminlabs/lnschema-bionty/pull/184) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-07 |
⬆️ Transient download bar | [182](https://github.com/laminlabs/lnschema-bionty/pull/182) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-05 | 0.30.4
📝 A proper landing page | [181](https://github.com/laminlabs/lnschema-bionty/pull/181) | [falexwolf](https://github.com/falexwolf) | 2023-09-02 | 0.30.3
♻️ Add DB-facing constructor | [180](https://github.com/laminlabs/lnschema-bionty/pull/180) | [falexwolf](https://github.com/falexwolf) | 2023-08-28 | 0.30.1
🎨 Make species not nullable in Gene, Protein, CellType | [179](https://github.com/laminlabs/lnschema-bionty/pull/179) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-24 |
♻️ Use `CanValidate` & `HasParents` | [176](https://github.com/laminlabs/lnschema-bionty/pull/176) | [falexwolf](https://github.com/falexwolf) | 2023-08-23 | 0.30.0
⬆️ Updated bionty version | [175](https://github.com/laminlabs/lnschema-bionty/pull/175) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-22 |
⬆️ Bionty 0.30.1 | [174](https://github.com/laminlabs/lnschema-bionty/pull/174) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-17 |
🚚 Rename map_synonyms to standardize | [173](https://github.com/laminlabs/lnschema-bionty/pull/173) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-16 | 0.29.5
📝 Refactored docs | [172](https://github.com/laminlabs/lnschema-bionty/pull/172) | [falexwolf](https://github.com/falexwolf) | 2023-08-12 | 0.29.4
♻️ Add ParentsAware | [171](https://github.com/laminlabs/lnschema-bionty/pull/171) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-11 | 0.29.3
🎨 Use logger.save | [170](https://github.com/laminlabs/lnschema-bionty/pull/170) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-07 | 0.29.2
🔊 Refactored logging msg | [169](https://github.com/laminlabs/lnschema-bionty/pull/169) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-07 |
⬆️ Updated bionty | [168](https://github.com/laminlabs/lnschema-bionty/pull/168) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-06 | 0.29.1
🚚 Rename ORM to Registry | [167](https://github.com/laminlabs/lnschema-bionty/pull/167) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-05 |
🎇 Added stable_id to Gene | [166](https://github.com/laminlabs/lnschema-bionty/pull/166) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-31 | 0.29.0
⬆️ Updated bionty to 0.28 | [165](https://github.com/laminlabs/lnschema-bionty/pull/165) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-31 |
🚚 Rename select to filter | [164](https://github.com/laminlabs/lnschema-bionty/pull/164) | [falexwolf](https://github.com/falexwolf) | 2023-07-31 |
🎨 Switch biontysource id to hash id | [163](https://github.com/laminlabs/lnschema-bionty/pull/163) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-25 | 0.28.2
🚸 New settings `auto_save_parents` | [162](https://github.com/laminlabs/lnschema-bionty/pull/162) | [falexwolf](https://github.com/falexwolf) | 2023-07-25 | 0.28.1
🎨 Link all entities to files and datasets | [160](https://github.com/laminlabs/lnschema-bionty/pull/160) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-24 | 0.28.0
🚚 Replace lamin_logger with lamin_utils | [161](https://github.com/laminlabs/lnschema-bionty/pull/161) | [falexwolf](https://github.com/falexwolf) | 2023-07-24 |
✏️ Fix docstrings | [159](https://github.com/laminlabs/lnschema-bionty/pull/159) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-21 | 0.27.4
🎨 Make species name unique | [158](https://github.com/laminlabs/lnschema-bionty/pull/158) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-21 |
🚑  Split previous migrations into 2 scripts | [156](https://github.com/laminlabs/lnschema-bionty/pull/156) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-20 | 0.27.3
⚡️ Fix migration 008 | [155](https://github.com/laminlabs/lnschema-bionty/pull/155) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-20 | 0.27.2
✏️ Fix docs warnings | [154](https://github.com/laminlabs/lnschema-bionty/pull/154) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-20 | 0.27.1
📝 Add examples to docstring | [153](https://github.com/laminlabs/lnschema-bionty/pull/153) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-20 |
🎨 Gene table unique on ensembl id | [152](https://github.com/laminlabs/lnschema-bionty/pull/152) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-18 | 0.27.0
🎨 Fix migration | [150](https://github.com/laminlabs/lnschema-bionty/pull/150) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-18 |
✅ Add integrity test | [151](https://github.com/laminlabs/lnschema-bionty/pull/151) | [falexwolf](https://github.com/falexwolf) | 2023-07-18 |
🚚 Rename Readout to ExperimentalFactor | [149](https://github.com/laminlabs/lnschema-bionty/pull/149) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-17 |
⬆️ Update bionty | [148](https://github.com/laminlabs/lnschema-bionty/pull/148) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-10 | 0.26.3
🚸 Trigger instance loading for users | [147](https://github.com/laminlabs/lnschema-bionty/pull/147) | [falexwolf](https://github.com/falexwolf) | 2023-07-06 | 0.26.2
⚡️ Speed up parents ingestion | [146](https://github.com/laminlabs/lnschema-bionty/pull/146) | [falexwolf](https://github.com/falexwolf) | 2023-07-04 | 0.26.1
🐛 Added missing migration | [145](https://github.com/laminlabs/lnschema-bionty/pull/145) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-03 | 0.26.0
🐛 Fix species bug for no-species orms | [144](https://github.com/laminlabs/lnschema-bionty/pull/144) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-02 | 0.25.5
🚸 Add settings | [142](https://github.com/laminlabs/lnschema-bionty/pull/142) | [falexwolf](https://github.com/falexwolf) | 2023-06-30 | 0.25.4
⬆️ Update bionty version | [143](https://github.com/laminlabs/lnschema-bionty/pull/143) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-30 | 0.25.3
🚑️ Allow bulk saving parents without causing conflicts | [141](https://github.com/laminlabs/lnschema-bionty/pull/141) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-30 | 0.25.2
🚚 Move init from lookup code from lamindb here | [140](https://github.com/laminlabs/lnschema-bionty/pull/140) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-29 | 0.25.1
✨ Added self-referential `parents`, renamed `abbr` and `description` | [139](https://github.com/laminlabs/lnschema-bionty/pull/139) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-29 | 0.25.0
♻️ Replaced ln.parse with orm.from_values | [138](https://github.com/laminlabs/lnschema-bionty/pull/138) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-27 | 0.24.0
🚚 Move add_synonym to BaseORM | [137](https://github.com/laminlabs/lnschema-bionty/pull/137) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-22 | 0.23.5
⬆️ Fix synonyms duplication check | [136](https://github.com/laminlabs/lnschema-bionty/pull/136) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-22 |
⬆️ Updated bionty | [135](https://github.com/laminlabs/lnschema-bionty/pull/135) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-20 | 0.23.4
🚑️ Do not check existing synonyms when db table is empty | [134](https://github.com/laminlabs/lnschema-bionty/pull/134) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-20 |
🎨 Create multiple records with .from_bionty | [133](https://github.com/laminlabs/lnschema-bionty/pull/133) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-20 | 0.23.3
📈 Save to DB if record already exists for add_synonyms | [132](https://github.com/laminlabs/lnschema-bionty/pull/132) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-20 | 0.23.2
🚚 Fixed all related_names | [131](https://github.com/laminlabs/lnschema-bionty/pull/131) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-20 | 0.23.1
🏷️ Change name to a required field for ontology tables | [130](https://github.com/laminlabs/lnschema-bionty/pull/130) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-19 | 0.23.0
⬆️ Updated bionty version | [129](https://github.com/laminlabs/lnschema-bionty/pull/129) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-17 | 0.22.2
⬆️ Update to bionty 0.21.3 | [128](https://github.com/laminlabs/lnschema-bionty/pull/128) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-16 | 0.22.1
🎨 Consolidate schema, remove non-crucial fields | [127](https://github.com/laminlabs/lnschema-bionty/pull/127) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-16 | 0.22.0
⬆️ Update bionty | [126](https://github.com/laminlabs/lnschema-bionty/pull/126) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-12 | 0.21.4
🚚 Rename `source_key` to `source` in BiontySource table | [125](https://github.com/laminlabs/lnschema-bionty/pull/125) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-10 | 0.21.3
🚚 Rename Featureset to FeatureSet | [124](https://github.com/laminlabs/lnschema-bionty/pull/124) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-10 | 0.21.2
👷 Simplify docs & CI | [123](https://github.com/laminlabs/lnschema-bionty/pull/123) | [falexwolf](https://github.com/falexwolf) | 2023-06-10 |
⏪ Change species id back to 4 char | [122](https://github.com/laminlabs/lnschema-bionty/pull/122) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-09 | 0.21.1
🎨 Change on_delete to PROTECT | [121](https://github.com/laminlabs/lnschema-bionty/pull/121) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-09 | 0.21.0
🚑 Fixed null issues | [120](https://github.com/laminlabs/lnschema-bionty/pull/120) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-09 | 0.20.0
⬆️ Updated bionty to 0.17.0 | [119](https://github.com/laminlabs/lnschema-bionty/pull/119) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-08 | 0.19.0
🎨 Remove unnecessary null=True, blank=True | [118](https://github.com/laminlabs/lnschema-bionty/pull/118) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-08 | 0.19a6
🚑 Fix species type | [117](https://github.com/laminlabs/lnschema-bionty/pull/117) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-08 | 0.19a5
♻️ Simplified species code | [116](https://github.com/laminlabs/lnschema-bionty/pull/116) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-08 | 0.19a4
🚚 Rename BiontyVersions to BiontySources | [115](https://github.com/laminlabs/lnschema-bionty/pull/115) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-07 | 0.19a3
⬆️ Updated versions table | [114](https://github.com/laminlabs/lnschema-bionty/pull/114) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-05 | 0.19a2
🚚 Migrate `lnschema-bionty` to Django | [112](https://github.com/laminlabs/lnschema-bionty/pull/112) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-05 | 0.19a1
➖ Remove nbproject from dependencies | [113](https://github.com/laminlabs/lnschema-bionty/pull/113) | [Koncopd](https://github.com/Koncopd) | 2023-06-04 |
✨ Added `Features.pathways` | [111](https://github.com/laminlabs/lnschema-bionty/pull/111) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-02 | 0.18.3
🔥 Fix CI and removed migrations test | [110](https://github.com/laminlabs/lnschema-bionty/pull/110) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-01 |
✨ Add `add_synonym` method | [109](https://github.com/laminlabs/lnschema-bionty/pull/109) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-01 |
🚑 Must pass a species when creating record from lookup | [108](https://github.com/laminlabs/lnschema-bionty/pull/108) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-30 | 0.18.2
✨ Added `Pathway.genes` | [107](https://github.com/laminlabs/lnschema-bionty/pull/107) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-30 | 0.18.1
🚑 Fix created_by_id in Readout | [106](https://github.com/laminlabs/lnschema-bionty/pull/106) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-28 | 0.18.0
🎨 Change .bionty to a method | [105](https://github.com/laminlabs/lnschema-bionty/pull/105) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-28 |
🚑 Default species to None and not pass to Bionty | [104](https://github.com/laminlabs/lnschema-bionty/pull/104) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-27 | 0.18a6
🚑 Fix 0.18.0 sqlite migration script | [103](https://github.com/laminlabs/lnschema-bionty/pull/103) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-27 |
✨ Add `synonyms`, `definition`, `short_name` columns | [102](https://github.com/laminlabs/lnschema-bionty/pull/102) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-27 | 0.18a5
🚑 Fix table name for id_encoder | [101](https://github.com/laminlabs/lnschema-bionty/pull/101) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-27 |
⬆️ Update lamindb and bionty versions | [100](https://github.com/laminlabs/lnschema-bionty/pull/100) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-27 |
🏷️ Restored Optional type annotation | [99](https://github.com/laminlabs/lnschema-bionty/pull/99) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-26 |
🏗️ Remove SQL-level schema modules | [96](https://github.com/laminlabs/lnschema-bionty/pull/96) | [falexwolf](https://github.com/falexwolf) | 2023-05-25 | 0.18a2
🚑 Fix last migration | [98](https://github.com/laminlabs/lnschema-bionty/pull/98) | [falexwolf](https://github.com/falexwolf) | 2023-05-25 | 0.17.1
🍱 Add CreatedBy and CreatedAt to all entities | [95](https://github.com/laminlabs/lnschema-bionty/pull/95) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-25 | 0.17.0
🚚 Rename bt.Entity to bt.Bionty | [94](https://github.com/laminlabs/lnschema-bionty/pull/94) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-25 |
⬆️ Upgrade to bionty 0.13 | [92](https://github.com/laminlabs/lnschema-bionty/pull/92) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-09 | 0.16.4
✨ Added synonyms field to CellMarker | [91](https://github.com/laminlabs/lnschema-bionty/pull/91) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-09 | 0.16.3
💚 Fix dependencies | [90](https://github.com/laminlabs/lnschema-bionty/pull/90) | [sunnyosun](https://github.com/sunnyosun) | 2023-04-27 | 0.16.2
🎨 Move ._entity to private | [89](https://github.com/laminlabs/lnschema-bionty/pull/89) | [sunnyosun](https://github.com/sunnyosun) | 2023-04-27 | 0.16.1
💥 Enable `.bionty` for accessing bionty functionalities | [87](https://github.com/laminlabs/lnschema-bionty/pull/87) | [sunnyosun](https://github.com/sunnyosun) | 2023-04-24 | 0.16.0
⚡ Fix adding species | [84](https://github.com/laminlabs/lnschema-bionty/pull/84) | [sunnyosun](https://github.com/sunnyosun) | 2023-04-19 | 0.15.2
✨ Add ._entity to knowledge class for features parsing | [83](https://github.com/laminlabs/lnschema-bionty/pull/83) | [sunnyosun](https://github.com/sunnyosun) | 2023-04-18 | 0.15.1
🎨 New design of the knowledge API | [80](https://github.com/laminlabs/lnschema-bionty/pull/80) | [sunnyosun](https://github.com/sunnyosun) | 2023-04-17 | 0.15.0
♻️ Refactor knowledge | [77](https://github.com/laminlabs/lnschema-bionty/pull/77) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-28 | 0.14.0
🐛 Fix import | [76](https://github.com/laminlabs/lnschema-bionty/pull/76) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-27 | 0.13.1
✨ Added Readout | [75](https://github.com/laminlabs/lnschema-bionty/pull/75) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-27 | 0.13.0
📝 Move knowledge guide from lamindb here | [71](https://github.com/laminlabs/lnschema-bionty/pull/71) | [falexwolf](https://github.com/falexwolf) | 2023-03-27 |
⬆️ Updated bionty and lamindb deps | [74](https://github.com/laminlabs/lnschema-bionty/pull/74) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-27 | 0.12.2
👷 Upgrade to latest cookiecutter | [73](https://github.com/laminlabs/lnschema-bionty/pull/73) | [falexwolf](https://github.com/falexwolf) | 2023-03-27 |
🚑 Fix `get_term` | [72](https://github.com/laminlabs/lnschema-bionty/pull/72) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-25 | 0.12.1
♻️ Switch to class property | [70](https://github.com/laminlabs/lnschema-bionty/pull/70) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-24 | 0.12.0
✨ Expose bionty functions with knowledge decorator | [69](https://github.com/laminlabs/lnschema-bionty/pull/69) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-24 | 0.11.0
🐛 Fix Readout population | [68](https://github.com/laminlabs/lnschema-bionty/pull/68) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-23 | 0.10.1
⬆️ Update CellMarker columns for bionty 0.10 | [64](https://github.com/laminlabs/lnschema-bionty/pull/64) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-21 | 0.10.0
✨ Add CellLine, Pathway, Phenotype | [63](https://github.com/laminlabs/lnschema-bionty/pull/63) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-21 | 0.9.0
💚 Fix CI | [62](https://github.com/laminlabs/lnschema-bionty/pull/62) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-21 |
⬆️ Upgrade to bionty 0.9.0 | [61](https://github.com/laminlabs/lnschema-bionty/pull/61) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-20 | 0.8.1
🎨 Allow hashing external IDs | [60](https://github.com/laminlabs/lnschema-bionty/pull/60) | [falexwolf](https://github.com/falexwolf) | 2023-03-10 |
⬆️ Stable release of bionty 0.8.0 | [59](https://github.com/laminlabs/lnschema-bionty/pull/59) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-09 | 0.8.0
⬆️ Bionty>=0.8rc3 | [58](https://github.com/laminlabs/lnschema-bionty/pull/58) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-09 | 0.8rc2
✨ Use ontology_id as the id for Tissue, CellType, Disease | [57](https://github.com/laminlabs/lnschema-bionty/pull/57) | [sunnyosun](https://github.com/sunnyosun) | 2023-03-07 | 0.8.0rc1
⬆️ Upgrade bionty | [56](https://github.com/laminlabs/lnschema-bionty/pull/56) | [falexwolf](https://github.com/falexwolf) | 2023-03-06 |
🔥 Remove migration files | [51](https://github.com/laminlabs/lnschema-bionty/pull/51) | [sunnyosun](https://github.com/sunnyosun) | 2023-02-14 | 0.7.0
⬆️ Upgrade and rename `lndb_setup` to `lndb` (v0.32.0) | [49](https://github.com/laminlabs/lnschema-bionty/pull/49) | [bpenteado](https://github.com/bpenteado) | 2023-02-14 | 0.6.9
🐛 Fixed taxon_id type | [48](https://github.com/laminlabs/lnschema-bionty/pull/48) | [sunnyosun](https://github.com/sunnyosun) | 2023-01-17 | 0.6.8
⬆️ Upgrade dependencies | [47](https://github.com/laminlabs/lnschema-bionty/pull/47) | [sunnyosun](https://github.com/sunnyosun) | 2023-01-17 | 0.6.7
⏪ Revert the last PR | [46](https://github.com/laminlabs/lnschema-bionty/pull/46) | [sunnyosun](https://github.com/sunnyosun) | 2023-01-17 |
🐛 Fixed typo for postgres | [45](https://github.com/laminlabs/lnschema-bionty/pull/45) | [sunnyosun](https://github.com/sunnyosun) | 2023-01-16 | 0.6.6
🎨 Change `Species.taxon_id` type to int | [43](https://github.com/laminlabs/lnschema-bionty/pull/43) | [sunnyosun](https://github.com/sunnyosun) | 2023-01-13 |
👷 Extend CI to py3.8-3.10 | [42](https://github.com/laminlabs/lnschema-bionty/pull/42) | [sunnyosun](https://github.com/sunnyosun) | 2023-01-12 |
🚚 Rename `Species.common_name` to `Species.name` | [41](https://github.com/laminlabs/lnschema-bionty/pull/41) | [falexwolf](https://github.com/falexwolf) | 2023-01-05 |
🐛 Fix migration for sqlite | [40](https://github.com/laminlabs/lnschema-bionty/pull/40) | [falexwolf](https://github.com/falexwolf) | 2023-01-05 | 0.6.5
♻️ Treat link tables as in all other schema modules | [39](https://github.com/laminlabs/lnschema-bionty/pull/39) | [falexwolf](https://github.com/falexwolf) | 2023-01-05 | 0.6.4
🚚 Move knowledge version tables into module | [38](https://github.com/laminlabs/lnschema-bionty/pull/38) | [falexwolf](https://github.com/falexwolf) | 2023-01-05 | 0.6.3
🧪 Added test for ontology autopopulate | [37](https://github.com/laminlabs/lnschema-bionty/pull/37) | [sunnyosun](https://github.com/sunnyosun) | 2022-12-09 |
✅ Add migrations test | [36](https://github.com/laminlabs/lnschema-bionty/pull/36) | [falexwolf](https://github.com/falexwolf) | 2022-12-08 |
✨ Added bionty_version table | [35](https://github.com/laminlabs/lnschema-bionty/pull/35) | [sunnyosun](https://github.com/sunnyosun) | 2022-12-07 | 0.6.2
🎨 Updated bionty_versions | [34](https://github.com/laminlabs/lnschema-bionty/pull/34) | [sunnyosun](https://github.com/sunnyosun) | 2022-12-05 |
✨ Added `bionty_versions` table | [33](https://github.com/laminlabs/lnschema-bionty/pull/33) | [sunnyosun](https://github.com/sunnyosun) | 2022-11-18 | 0.6.1
🏗️ Introduce relationships, move Features table to core | [32](https://github.com/laminlabs/lnschema-bionty/pull/32) | [falexwolf](https://github.com/falexwolf) | 2022-11-17 | 0.6.0
⚡ Implemented knowledge as a decorator | [31](https://github.com/laminlabs/lnschema-bionty/pull/31) | [sunnyosun](https://github.com/sunnyosun) | 2022-11-11 | 0.5.4
✨ Added populator for ontologies | [30](https://github.com/laminlabs/lnschema-bionty/pull/30) | [sunnyosun](https://github.com/sunnyosun) | 2022-11-11 |
♻️ Refactor knowledge population | [29](https://github.com/laminlabs/lnschema-bionty/pull/29) | [falexwolf](https://github.com/falexwolf) | 2022-11-06 |
🐛 Fixed postgres migration script | [28](https://github.com/laminlabs/lnschema-bionty/pull/28) | [sunnyosun](https://github.com/sunnyosun) | 2022-11-06 | 0.5.3
✨ Use bionty to populate species | [27](https://github.com/laminlabs/lnschema-bionty/pull/27) | [sunnyosun](https://github.com/sunnyosun) | 2022-11-06 | 0.5.2
🐛 Fix prefix | [26](https://github.com/laminlabs/lnschema-bionty/pull/26) | [falexwolf](https://github.com/falexwolf) | 2022-11-03 | 0.5.1
🎨 Modularize and capitalize | [24](https://github.com/laminlabs/lnschema-bionty/pull/24) | [falexwolf](https://github.com/falexwolf) | 2022-11-03 | 0.5.0
🎨 Updated cell marker id gen | [23](https://github.com/laminlabs/lnschema-bionty/pull/23) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-25 | 0.4.5
✏️ Updated species id to be 3 chars | [22](https://github.com/laminlabs/lnschema-bionty/pull/22) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-24 | 0.4.4
🧑‍💻 Added naming convention | [20](https://github.com/laminlabs/lnschema-bionty/pull/20) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-20 |
🩹 Fix type annotations of primary keys | [19](https://github.com/laminlabs/lnschema-bionty/pull/19) | [falexwolf](https://github.com/falexwolf) | 2022-09-29 | 0.4.3
✏️ Changed ids to str | [18](https://github.com/laminlabs/lnschema-bionty/pull/18) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-29 | 0.4.2
🍱 Added `description` and `version` columns to the gene table | [17](https://github.com/laminlabs/lnschema-bionty/pull/17) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-27 | 0.4.1
🚚 Update primary keys to universal ids | [16](https://github.com/laminlabs/lnschema-bionty/pull/16) | [falexwolf](https://github.com/falexwolf) | 2022-09-22 | 0.4.0
🚚 Rename column in version table, add testdb, and migration script | [15](https://github.com/laminlabs/lnschema-bionty/pull/15) | [falexwolf](https://github.com/falexwolf) | 2022-09-22 | 0.3.1
✨ Add migrations infra | [14](https://github.com/laminlabs/lnschema-bionty/pull/14) | [falexwolf](https://github.com/falexwolf) | 2022-09-22 | 0.3.0
🩹 Added unique constraints | [13](https://github.com/laminlabs/lnschema-bionty/pull/13) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-22 |
🐛 Fixed API ref | [12](https://github.com/laminlabs/lnschema-bionty/pull/12) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-06 | 0.2.4
🎨 Import additional modules, species -> species_id | [11](https://github.com/laminlabs/lnschema-bionty/pull/11) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-28 | 0.2.3
🚚 Rename gene_symbol to symbol, protein_name to name | [10](https://github.com/laminlabs/lnschema-bionty/pull/10) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-28 | 0.2.2
⬆️ Update schema to match bionty 0.2.0 | [9](https://github.com/laminlabs/lnschema-bionty/pull/9) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-28 | 0.2.1
🚚 Rename `lndb-schema-bionty` to `lnschema-bionty` | [8](https://github.com/laminlabs/lnschema-bionty/pull/8) | [falexwolf](https://github.com/falexwolf) | 2022-08-19 | 0.2.0
🔧 Add schema module id | [7](https://github.com/laminlabs/lnschema-bionty/pull/7) | [falexwolf](https://github.com/falexwolf) | 2022-08-18 |
🍱 Updated the gene table to match new ensembl table | [6](https://github.com/laminlabs/lnschema-bionty/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-18 | 0.1.4
🎨 Changed type of `species` and `entrez_gene_id` in `gene` table to `int` | [5](https://github.com/laminlabs/lnschema-bionty/pull/5) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-15 | 0.1.3
🚚 Move `biolab` to `lnschema-wetlab` | [4](https://github.com/laminlabs/lnschema-bionty/pull/4) | [falexwolf](https://github.com/falexwolf) | 2022-07-31 |
✨ Introduced featureset to replace geneset and proteinset | [2](https://github.com/laminlabs/lnschema-biology/pull/2) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-31 | 0.1.2
🎨 Changed `resolution` to `platform` in `readout_type` | [commit](https://github.com/laminlabs/lnschema-biology/commit/14552dd71cea463157f29201126ca9a2e259aded) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-23 | 0.1.1
🚚 Move code from `lamindb-schema` | [1](https://github.com/laminlabs/lnschema-biology/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-23 | 0.1.0
